@@ -37,7 +37,9 @@ func init() {
 // and translates it to the equivalent `terraform-kubernetes-provider` schema format.
 //
 // Sometimes the Kubernetes attribute name doesn't match struct name
-//   e.g. `type ContainerPort struct` -> "ports" in YAML
+//
+//	e.g. `type ContainerPort struct` -> "ports" in YAML
+//
 // so we need to extract the JSON name from the StructField tag.
 // Finally, the attribute name is converted to snake case.
 func ToTerraformAttributeName(field *reflect.StructField, path string) string {
@@ -50,7 +52,9 @@ func ToTerraformAttributeName(field *reflect.StructField, path string) string {
 // and translates it to the equivalent `terraform-kubernetes-provider` schema format.
 //
 // Sometimes the Kubernetes block name doesn't match struct name
-//   e.g. `type ContainerPort struct` -> "ports" in YAML
+//
+//	e.g. `type ContainerPort struct` -> "ports" in YAML
+//
 // so we need to extract the JSON name from the StructField tag.
 // Next, the attribute name is converted to singular + snake case.
 func ToTerraformSubBlockName(field *reflect.StructField, path string) string {
@@ -79,6 +83,11 @@ func NormalizeTerraformName(s string, toSingular bool, path string) string {
 			return "strategy"
 		}
 
+	case "sources":
+		if strings.Contains(path, "volume.projected") {
+			return "sources"
+		}
+
 	case "limits":
 		if strings.Contains(path, "limit_range.spec") {
 			return "limit"
@@ -160,6 +169,12 @@ func ToTerraformResourceType(obj runtime.Object) string {
 		} else {
 			kind = "ingress"
 		}
+	case "CronJob":
+		if tmeta.APIVersion == "batch/v1" {
+			kind = "cron_job_v1"
+		} else {
+			kind = "cron_job"
+		}
 	default:
 		kind = NormalizeTerraformName(tmeta.Kind, false, "")
 	}
